aboutsummaryrefslogtreecommitdiff
path: root/common/fs.h
diff options
context:
space:
mode:
authorMax Horn2009-01-23 04:45:44 +0000
committerMax Horn2009-01-23 04:45:44 +0000
commit14c5bbbccf30f333b92092ca55063b338335c3a5 (patch)
tree80cfc99351a2333461bbbb6e9437780921ad2edb /common/fs.h
parent9861afd8fde386ffc740ab12fad26f2d41213821 (diff)
downloadscummvm-rg350-14c5bbbccf30f333b92092ca55063b338335c3a5.tar.gz
scummvm-rg350-14c5bbbccf30f333b92092ca55063b338335c3a5.tar.bz2
scummvm-rg350-14c5bbbccf30f333b92092ca55063b338335c3a5.zip
Renamed Archive::openFile to createReadStreamForMember
svn-id: r36021
Diffstat (limited to 'common/fs.h')
-rw-r--r--common/fs.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/fs.h b/common/fs.h
index 61ce21bec5..b8e6aeecc4 100644
--- a/common/fs.h
+++ b/common/fs.h
@@ -243,7 +243,7 @@ public:
* Again, only SLASHES are used as separators independently from the
* underlying file system.
*
* Relative paths can be specified when calling matching functions like openFile(),
* hasFile(), listMatchingMembers() and listMembers(). Please see the function
* specific comments for more information.
*
@@ -333,7 +333,7 @@ public:
* Open the specified file. A full match of relative path and filename is needed
* for success.
*/
- virtual SeekableReadStream *openFile(const String &name) const;
+ virtual SeekableReadStream *createReadStreamForMember(const String &name) const;
};
@@ -243,7 +243,7 @@ public:
* underlying file system.
*
- * Relative paths can be specified when calling matching functions like openFile(),
+ * Relative paths can be specified when calling matching functions like createReadStreamForMember(),
* hasFile(), listMatchingMembers() and listMembers(). Please see the function
* specific comments for more information.